summaryrefslogtreecommitdiffstats
path: root/media/mca
diff options
context:
space:
mode:
authorAndy McFadden <fadden@android.com>2012-12-18 09:48:38 -0800
committerAndy McFadden <fadden@android.com>2012-12-18 11:22:21 -0800
commitd47f7d8b5fe3a3861d7cbdc5f912235407823c8e (patch)
treeb4c4e636bac379ded38550ade39e39c2d86467ea /media/mca
parent4e7ec240cabbdf3ac9776a691be0a46ea4e2e69e (diff)
downloadframeworks_base-d47f7d8b5fe3a3861d7cbdc5f912235407823c8e.zip
frameworks_base-d47f7d8b5fe3a3861d7cbdc5f912235407823c8e.tar.gz
frameworks_base-d47f7d8b5fe3a3861d7cbdc5f912235407823c8e.tar.bz2
Rename ISurfaceTexture and SurfaceTexture
The C++ class names don't match what the classes do, so rename ISurfaceTexture to IGraphicBufferProducer, and SurfaceTexture to GLConsumer. Bug 7736700 Change-Id: I08e677faf2ebb418ef131d0a8008e01037db0e50
Diffstat (limited to 'media/mca')
-rw-r--r--media/mca/filterfw/jni/jni_gl_environment.cpp8
-rw-r--r--media/mca/filterfw/jni/jni_gl_environment.h2
-rw-r--r--media/mca/filterfw/native/core/gl_env.cpp6
-rw-r--r--media/mca/filterfw/native/core/gl_env.h6
4 files changed, 11 insertions, 11 deletions
diff --git a/media/mca/filterfw/jni/jni_gl_environment.cpp b/media/mca/filterfw/jni/jni_gl_environment.cpp
index 3c596a4..b64004e 100644
--- a/media/mca/filterfw/jni/jni_gl_environment.cpp
+++ b/media/mca/filterfw/jni/jni_gl_environment.cpp
@@ -23,7 +23,7 @@
#include <media/mediarecorder.h>
#include "native/core/gl_env.h"
-#include <gui/ISurfaceTexture.h>
+#include <gui/IGraphicBufferProducer.h>
#include <gui/SurfaceTextureClient.h>
#include <utils/Errors.h>
#include <system/window.h>
@@ -33,7 +33,7 @@ using android::filterfw::GLEnv;
using android::filterfw::WindowHandle;
using android::MediaRecorder;
using android::sp;
-using android::ISurfaceTexture;
+using android::IGraphicBufferProducer;
using android::SurfaceTextureClient;
@@ -284,10 +284,10 @@ jint Java_android_filterfw_core_GLEnvironment_nativeAddSurfaceFromMediaRecorder(
// Ask the mediarecorder to return a handle to a surfacemediasource
// This will talk to the StageFrightRecorder via MediaRecorderClient
// over binder calls
- sp<ISurfaceTexture> surfaceMS = mr->querySurfaceMediaSourceFromMediaServer();
+ sp<IGraphicBufferProducer> surfaceMS = mr->querySurfaceMediaSourceFromMediaServer();
if (surfaceMS == NULL) {
ALOGE("GLEnvironment: Error- MediaRecorder returned a null \
- <ISurfaceTexture> handle.");
+ <IGraphicBufferProducer> handle.");
return -1;
}
sp<SurfaceTextureClient> surfaceTC = new SurfaceTextureClient(surfaceMS);
diff --git a/media/mca/filterfw/jni/jni_gl_environment.h b/media/mca/filterfw/jni/jni_gl_environment.h
index af9c744..9dd7102 100644
--- a/media/mca/filterfw/jni/jni_gl_environment.h
+++ b/media/mca/filterfw/jni/jni_gl_environment.h
@@ -68,7 +68,7 @@ Java_android_filterfw_core_GLEnvironment_nativeAddSurfaceWidthHeight(JNIEnv* env
// The call to hook up the SurfaceMediaSource (in MediaServer) to the GL.
// We get a sp<ISurfaceTexure> from the MediaServer and talks to MediaServer
// over a binder interface. GL hooked up to the MediaServer by using the native
-// window created using the <ISurfaceTexture> handle
+// window created using the <IGraphicBufferProducer> handle
JNIEXPORT jint JNICALL
Java_android_filterfw_core_GLEnvironment_nativeAddSurfaceFromMediaRecorder(
JNIEnv* env,
diff --git a/media/mca/filterfw/native/core/gl_env.h b/media/mca/filterfw/native/core/gl_env.h
index b61785f..3c87195 100644
--- a/media/mca/filterfw/native/core/gl_env.h
+++ b/media/mca/filterfw/native/core/gl_env.h
@@ -27,7 +27,7 @@
#include <GLES2/gl2.h>
#include <EGL/egl.h>
-#include <gui/ISurfaceTexture.h>
+#include <gui/IGraphicBufferProducer.h>
#include <gui/SurfaceTextureClient.h>
namespace android {
@@ -236,8 +236,8 @@ class GLEnv {
// Dummy surface for context
sp<ANativeWindow> window_;
- // Dummy SurfaceTexture for context
- sp<SurfaceTexture> surfaceTexture_;
+ // Dummy GLConsumer for context
+ sp<GLConsumer> surfaceTexture_;
// The maximum surface id used.
int max_surface_id_;
diff --git a/media/mca/filterfw/native/core/gl_env.cpp b/media/mca/filterfw/native/core/gl_env.cpp
index 738b8e0..8ed82e2 100644
--- a/media/mca/filterfw/native/core/gl_env.cpp
+++ b/media/mca/filterfw/native/core/gl_env.cpp
@@ -159,9 +159,9 @@ bool GLEnv::InitWithNewContext() {
return false;
}
- // Create dummy surface using a SurfaceTexture
- surfaceTexture_ = new SurfaceTexture(0);
- window_ = new SurfaceTextureClient(static_cast<sp<ISurfaceTexture> >(
+ // Create dummy surface using a GLConsumer
+ surfaceTexture_ = new GLConsumer(0);
+ window_ = new SurfaceTextureClient(static_cast<sp<IGraphicBufferProducer> >(
surfaceTexture_->getBufferQueue()));
surfaces_[0] = SurfaceWindowPair(eglCreateWindowSurface(display(), config, window_.get(), NULL), NULL);